# physipandas : a pandas accessor and types for physipy

[physipy](https://github.com/mocquin/physipy) allows you to handle physical quantities in python. Using pandas [extension interface](https://pandas.pydata.org/docs/development/extending.html), `physipandas`` provides additionnal features for great integration of physipy with pandas Series and Dataframe.

# Installation

# Documentation
See the notebooks in the [docs](./docs) folder.
